

TAPQuery
=====================

.. currentmodule:: pyvo.dal.tap

.. autoclass:: TAPQuery
   :show-inheritance:

   
     
   

   
   
   

   
   

   .. rubric:: Methods Summary

   .. autosummary::
   
      ~TAPQuery.execute_stream
      ~TAPQuery.getqueryurl
      ~TAPQuery.submit

   
   

   
   
   

   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: execute_stream
   .. automethod:: getqueryurl
   .. automethod:: submit

   
   